@@ -8,19 +8,30 @@ from client_sdk_python.module import (
 from eth_utils.hexadecimal import remove_0x_prefix
 from client_sdk_python.utils.encoding import parse_str
 from client_sdk_python.utils.transactions import send_obj_transaction, call_obj
-from platon_account.internal.transactions import bech32_address_bytes
+from client_sdk_python.packages.platon_account.internal.transactions import bech32_address_bytes
+from client_sdk_python.packages.platon_keys.utils.address import BASE_ADDRESS
+from client_sdk_python.utils.encoding import tobech32address
 
 
 class Ppos(Module):
     # If you want to get the result of the transaction, please set it to True,
     # if you only want to get the transaction hash, please set it to False
     need_analyze = True
+    need_quota_gas = True
 
-    def createStaking(self, typ, benifit_address, node_id, external_id, node_name, website, details, amount,
-                      program_version, program_version_sign, bls_pubkey, bls_proof, pri_key, reward_per, transaction_cfg=None):
+    def __init__(self, web3):
+        super().__init__(web3)
+        self.stakingAddress = tobech32address(self.web3.net_type, BASE_ADDRESS['sta'])
+        self.delegateRewardAddress = tobech32address(self.web3.net_type, BASE_ADDRESS['del'])
+        self.penaltyAddress = tobech32address(self.web3.net_type, BASE_ADDRESS['pen'])
+        self.restrictingAddress = tobech32address(self.web3.net_type, BASE_ADDRESS['res'])
+
+    def createStaking(self,  benifit_address, node_id, external_id, node_name, website, details, amount,program_version,
+                       program_version_sign, bls_pubkey, bls_proof, pri_key, reward_per, typ=2, transaction_cfg=None):
         """
         Initiate Staking
-        :param typ: Indicates whether the account free amount or the account's lock amount is used for staking, 0: free amount; 1: lock amount
+        :param typ: Indicates whether the account free amount or the account's lock amount is used for staking, 0: free amount; 1: lock amount;
+                    2: Give priority to lock amount , use free amount provided that staking amount over lock amount
         :param benifit_address: Income account for accepting block rewards and staking rewards
         :param node_id: The idled node Id (also called the candidate's node Id)
         :param external_id: External Id (with length limit, Id for the third party to pull the node description)
@@ -53,7 +64,7 @@ class Ppos(Module):
                                     rlp.encode(amount), rlp.encode(reward_per), rlp.encode(program_version),
                                     rlp.encode(bytes.fromhex(program_version_sign)), rlp.encode(bytes.fromhex(bls_pubkey)),
                                     rlp.encode(bytes.fromhex(bls_proof))])).hex()
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
     def editCandidate(self, benifit_address, node_id, external_id, node_name, website, details, pri_key, reward_per, transaction_cfg=None):
         """
@@ -82,12 +93,13 @@ class Ppos(Module):
         data = HexBytes(rlp.encode([rlp.encode(int(1001)), rlp.encode(benifit_address), rlp.encode(bytes.fromhex(node_id)),
                                     rlp.encode(reward_per),
                                     rlp.encode(external_id), rlp.encode(node_name), rlp.encode(website), rlp.encode(details)])).hex()
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
-    def increaseStaking(self, typ, node_id, amount, pri_key, transaction_cfg=None):
+    def increaseStaking(self, node_id, amount, pri_key, typ=2, transaction_cfg=None):
         """
         Increase staking
-        :param typ: Indicates whether the account free amount or the account's lock amount is used for staking, 0: free amount; 1: lock amount
+        :param typ: Indicates whether the account free amount or the account's lock amount is used for staking, 0: free amount; 1: lock amount;
+                    2: Give priority to lock amount , use free amount provided that staking amount over lock amount
         :param node_id: The idled node Id (also called the candidate's node Id)
         :param amount: staking von (unit:von, 1LAT = 10**18 von)
         :param pri_key: Private key for transaction
@@ -102,7 +114,7 @@ class Ppos(Module):
                 if is not need analyze return transaction hash
         """
         data = HexBytes(rlp.encode([rlp.encode(int(1002)), rlp.encode(bytes.fromhex(node_id)), rlp.encode(typ), rlp.encode(amount)])).hex()
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
     def withdrewStaking(self, node_id, pri_key, transaction_cfg=None):
         """
@@ -120,7 +132,7 @@ class Ppos(Module):
                 if is not need analyze return transaction hash
         """
         data = rlp.encode([rlp.encode(int(1003)), rlp.encode(bytes.fromhex(node_id))])
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
     def delegate(self, typ, node_id, amount, pri_key, transaction_cfg=None):
         """
@@ -140,7 +152,7 @@ class Ppos(Module):
                   if is not need analyze return transaction hash
         """
         data = rlp.encode([rlp.encode(int(1004)), rlp.encode(typ), rlp.encode(bytes.fromhex(node_id)), rlp.encode(amount)])
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
     def withdrewDelegate(self, staking_blocknum, node_id, amount, pri_key, transaction_cfg=None):
         """
@@ -160,7 +172,7 @@ class Ppos(Module):
                   if is not need analyze return transaction hash
         """
         data = rlp.encode([rlp.encode(int(1005)), rlp.encode(staking_blocknum), rlp.encode(bytes.fromhex(node_id)), rlp.encode(amount)])
-        return send_obj_transaction(self, data, self.web3.stakingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.stakingAddress, pri_key, transaction_cfg)
 
     def getVerifierList(self, from_address=None):
         """
@@ -170,7 +182,7 @@ class Ppos(Module):
         todo fill
         """
         data = rlp.encode([rlp.encode(int(1100))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         parse = parse_str(raw_data)
         try:
             raw_data = parse["Ret"]
@@ -187,7 +199,7 @@ class Ppos(Module):
         todo fill
         """
         data = rlp.encode([rlp.encode(int(1101))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         parse = parse_str(raw_data)
         try:
             raw_data = parse["Ret"]
@@ -204,7 +216,7 @@ class Ppos(Module):
         todo fill
         """
         data = rlp.encode([rlp.encode(int(1102))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         parse = parse_str(raw_data)
         try:
             raw_data = parse["Ret"]
@@ -227,7 +239,7 @@ class Ppos(Module):
         """
         del_addr = bech32_address_bytes(del_addr)
         data = rlp.encode([rlp.encode(int(1103)), rlp.encode(del_addr)])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         return parse_str(raw_data)
 
     def getDelegateInfo(self, staking_blocknum, del_address, node_id, from_address=None):
@@ -242,7 +254,7 @@ class Ppos(Module):
         """
         del_address = bech32_address_bytes(del_address)
         data = rlp.encode([rlp.encode(int(1104)), rlp.encode(staking_blocknum), rlp.encode(del_address), rlp.encode(bytes.fromhex(node_id))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         receive = json.loads(str(raw_data, encoding="utf8"))
         try:
             raw_data_dict = receive["Ret"]
@@ -265,7 +277,7 @@ class Ppos(Module):
         todo fill
         """
         data = rlp.encode([rlp.encode(int(1105)), rlp.encode(bytes.fromhex(node_id))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         parse = str(raw_data, encoding="utf8").replace('\\', '').replace('"{', '{').replace('}"', '}')
         receive = json.loads(parse)
         try:
@@ -299,7 +311,7 @@ class Ppos(Module):
                 if is not need analyze return transaction hash
         """
         data = rlp.encode([rlp.encode(int(3000)), rlp.encode(typ), rlp.encode(data)])
-        return send_obj_transaction(self, data, self.web3.penaltyAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.penaltyAddress, pri_key, transaction_cfg)
 
     def checkDuplicateSign(self, typ, node_id, block_number, from_address=None):
         """
@@ -312,7 +324,7 @@ class Ppos(Module):
         todo fill
         """
         data = rlp.encode([rlp.encode(int(3001)), rlp.encode(int(typ)), rlp.encode(bytes.fromhex(node_id)), rlp.encode(block_number)])
-        raw_data = call_obj(self, from_address, self.web3.penaltyAddress, data)
+        raw_data = call_obj(self, from_address, self.penaltyAddress, data)
         receive = str(raw_data, encoding="ISO-8859-1")
         if receive == "":
             return receive
@@ -353,7 +365,7 @@ class Ppos(Module):
             plan_list.append(v)
         rlp_list = rlp.encode(plan_list)
         data = rlp.encode([rlp.encode(int(4000)), rlp.encode(account), rlp_list])
-        return send_obj_transaction(self, data, self.web3.restrictingAddress, pri_key, transaction_cfg)
+        return send_obj_transaction(self, data, self.restrictingAddress, pri_key, transaction_cfg)
 
     def getRestrictingInfo(self, account, from_address=None):
         """
@@ -367,7 +379,7 @@ class Ppos(Module):
         #     account = account[2:]
         account = bech32_address_bytes(account)
         data = rlp.encode([rlp.encode(int(4100)), rlp.encode(account)])
-        raw_data = call_obj(self, from_address, self.web3.restrictingAddress, data)
+        raw_data = call_obj(self, from_address, self.restrictingAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         try:
             raw_data_dict = receive["Ret"]
@@ -383,7 +395,7 @@ class Ppos(Module):
 
     def getPackageReward(self, from_address=None):
         data = rlp.encode([rlp.encode(int(1200))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         ret = receive["Ret"]
         receive["Ret"] = int(str(ret), 16)
@@ -391,7 +403,7 @@ class Ppos(Module):
 
     def getStakingReward(self, from_address=None):
         data = rlp.encode([rlp.encode(int(1201))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         ret = receive["Ret"]
         receive["Ret"] = int(str(ret), 16)
@@ -399,7 +411,7 @@ class Ppos(Module):
 
     def getAvgPackTime(self, from_address=None):
         data = rlp.encode([rlp.encode(int(1202))])
-        raw_data = call_obj(self, from_address, self.web3.stakingAddress, data)
+        raw_data = call_obj(self, from_address, self.stakingAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         return receive
 
@@ -408,7 +420,7 @@ class Ppos(Module):
         tmp_from_address = bech32_address_bytes(from_address)
         data = [rlp.encode(int(5100)), rlp.encode(tmp_from_address), rlp.encode(node_id_bytes)]
         data = rlp.encode(data)
-        raw_data = call_obj(self, from_address, self.web3.delegateRewardAddress, data)
+        raw_data = call_obj(self, from_address, self.delegateRewardAddress, data)
         receive = json.loads(str(raw_data, encoding="ISO-8859-1"))
         try:
             raw_data_dict = receive["Ret"]
@@ -422,4 +434,4 @@ class Ppos(Module):
 
     def withdrawDelegateReward(self, pri_key, transaction_cfg=None):
         data = rlp.encode([rlp.encode(int(5000))])
-        return send_obj_transaction(self, data, self.web3.delegateRewardAddress, pri_key, transaction_cfg)
\ No newline at end of file
+        return send_obj_transaction(self, data, self.delegateRewardAddress, pri_key, transaction_cfg)
