@@ -8,7 +8,7 @@ from client_sdk_python.packages.eth_utils import (
     is_hex_address,
 )
 
-from ens import ENS
+from client_sdk_python.packages.ens import ENS
 from client_sdk_python.exceptions import (
     NameNotFound,
 )
